<?php
/**
 * Ce fichier contient l'action `supprimer_observations` lancée par un utilisateur autorisé pour
 * passer à l'état poubelle toutes les observations ou les anomalies fermées.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Cette action permet à l'utilisateur de passer à l'état poubelle, de façon sécurisée,
 * toutes les observations ou les anomalies fermées.
 *
 * Cette action est réservée aux utilisateurs pouvant instituer une observation.
 * Elle nécessite l'identifiant du type de contrôle et l'indicateur d'anomalie (oui/non).
 *
 * @param string $arguments Arguments de l'action ou null si l'action est appelée par une URL
 *
 * @return void
 */
function action_supprimer_observations_dist($arguments = null) {

	// Sécurisation.
	// Arguments attendus :
	// - l'identifiant du type de contrôle
	// - l'indicateur d'anomalie
	// - et l'id de l'auteur
	// Récupération des arguments de façon sécurisée.
	if (is_null($arguments)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arguments = $securiser_action();
	}
	list($type_controle, $est_anomalie, $id_auteur) = explode(':', $arguments);

	// Verification des autorisations :
	if (!autoriser('supprimer', 'observations')) {
		include_spip('inc/minipres');
		echo minipres();
		exit();
	}

	// On recherche toutes les observations ou anomalies déjà corrigées ou acquittées et associées
	// au type de contrôle.
	include_spip('inc/ezcheck_observation');
	$filtres = array(
		'type_controle' => $type_controle,
		'est_anomalie'  => $est_anomalie,
		'statut'        => 'fermee'
	);
	$ids = observation_repertorier($filtres, 'id_observation');

	// On boucle sur chaque observation et on la met à la poubelle.
	foreach ($ids as $_id_observation) {
		observation_cloturer('supprimer', $_id_observation, intval($id_auteur));
	}
}
